@@ -81,7 +81,7 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
         while self.step(self.basic_time_step) != -1:
 
-            if self.getTime() > 60:
+            if self.getTime() > 600:
                 break
 
             self.blink_led_lights(led_devices)
@@ -118,7 +118,7 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
             # Update log data every 5 minutes with energy values
             print(energy, f'\n{self.battery.remaining_energy_percentage * 100}% battery remaining')
-            with open('logs/ML_on_drone.json', 'w') as logfile:
+            with open('logs/ML_on_drone.json', 'a') as logfile:
                 json.dump(energy, logfile)
 
 
